Builds final production output files from compiled module graphs.
Summary
Functions
Bundle modules into separate chunks based on the chunk graph.
Bundle multiple ESM entries together and write Rolldown shared chunks.
Bundle modules into a single JS file and write output.
Bundle modules into a single in-memory JS bundle.
Functions
Bundle modules into separate chunks based on the chunk graph.
Bundle modules into a single JS file and write output.
Bundle modules into a single in-memory JS bundle.