Volt.Builder.Resolver (Volt v0.10.1)

Copy Markdown View Source

Resolve import specifiers to absolute file paths for the build graph.

Summary

Functions

Resolve an import specifier to an absolute file path.

Functions

absolute?(specifier)

resolve(specifier, importer, ctx)

Resolve an import specifier to an absolute file path.

Returns {:ok, path}, :skip (for externals/node builtins), or {:error, reason}.