Resolve import specifiers to absolute file paths for the build graph.
Summary
Functions
Resolve an import specifier to an absolute file path.
Resolve import specifiers to absolute file paths for the build graph.
Resolve an import specifier to an absolute file path.